Transaction execution helpers for TestContext.
These are async because they go through the mock RPC client, which is itself async.
Functions
- execute
- Build, sign, and send a transaction through the mock RPC client.
- execute_
with_ logs - Execute a transaction and return the signature together with program logs.